"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const defaultExperimentOptions = {
    isEligible: true,
};
function createExPlatClientReactHelpers(exPlatClient) {
    const useExperiment = (experimentName, providedOptions = {}) => {
        const options = {
            ...defaultExperimentOptions,
            ...providedOptions,
        };
        const [previousExperimentName] = (0, react_1.useState)(experimentName);
        const [state, setState] = (0, react_1.useState)([
            true,
            null,
        ]);
        (0, react_1.useEffect)(() => {
            let isSubscribed = true;
            if (options.isEligible) {
                exPlatClient.loadExperimentAssignment(experimentName).then((experimentAssignment) => {
                    if (isSubscribed) {
                        setState([false, experimentAssignment]);
                    }
                });
            }
            return () => {
                isSubscribed = false;
            };
        }, [experimentName, options.isEligible]);
        if (experimentName !== previousExperimentName &&
            !previousExperimentName.startsWith('explat_test')) {
            exPlatClient.config.logError({
                message: '[ExPlat] useExperiment: experimentName should never change between renders!',
            });
        }
        if (!options.isEligible) {
            return [false, null];
        }
        return state;
    };
    const Experiment = ({ defaultExperience, treatmentExperience, loadingExperience, name: experimentName, options, }) => {
        const [isLoading, experimentAssignment] = useExperiment(experimentName, options);
        if (isLoading) {
            return (0, jsx_runtime_1.jsx)(jsx_runtime_1.Fragment, { children: loadingExperience });
        }
        else if (!experimentAssignment?.variationName) {
            return (0, jsx_runtime_1.jsx)(jsx_runtime_1.Fragment, { children: defaultExperience });
        }
        return (0, jsx_runtime_1.jsx)(jsx_runtime_1.Fragment, { children: treatmentExperience });
    };
    const ProvideExperimentData = ({ children, name: experimentName, options, }) => {
        const [isLoading, experimentAssignment] = useExperiment(experimentName, options);
        return children(isLoading, experimentAssignment);
    };
    return {
        useExperiment,
        Experiment,
        ProvideExperimentData,
    };
}
exports.default = createExPlatClientReactHelpers;
//# sourceMappingURL=index.js.map