import { Fragment as _Fragment, jsx as _jsx } from "react/jsx-runtime";
import { useState, useEffect } from 'react';
const defaultExperimentOptions = {
    isEligible: true,
};
export default function createExPlatClientReactHelpers(exPlatClient) {
    const useExperiment = (experimentName, providedOptions = {}) => {
        const options = {
            ...defaultExperimentOptions,
            ...providedOptions,
        };
        const [previousExperimentName] = useState(experimentName);
        const [state, setState] = useState([
            true,
            null,
        ]);
        useEffect(() => {
            let isSubscribed = true;
            if (options.isEligible) {
                exPlatClient.loadExperimentAssignment(experimentName).then((experimentAssignment) => {
                    if (isSubscribed) {
                        setState([false, experimentAssignment]);
                    }
                });
            }
            return () => {
                isSubscribed = false;
            };
        }, [experimentName, options.isEligible]);
        if (experimentName !== previousExperimentName &&
            !previousExperimentName.startsWith('explat_test')) {
            exPlatClient.config.logError({
                message: '[ExPlat] useExperiment: experimentName should never change between renders!',
            });
        }
        if (!options.isEligible) {
            return [false, null];
        }
        return state;
    };
    const Experiment = ({ defaultExperience, treatmentExperience, loadingExperience, name: experimentName, options, }) => {
        const [isLoading, experimentAssignment] = useExperiment(experimentName, options);
        if (isLoading) {
            return _jsx(_Fragment, { children: loadingExperience });
        }
        else if (!experimentAssignment?.variationName) {
            return _jsx(_Fragment, { children: defaultExperience });
        }
        return _jsx(_Fragment, { children: treatmentExperience });
    };
    const ProvideExperimentData = ({ children, name: experimentName, options, }) => {
        const [isLoading, experimentAssignment] = useExperiment(experimentName, options);
        return children(isLoading, experimentAssignment);
    };
    return {
        useExperiment,
        Experiment,
        ProvideExperimentData,
    };
}
//# sourceMappingURL=index.js.map